@@ -84,7 +84,7 @@ def main():
   hostname, token = canvaslms.cli.login.load_credentials(config)
 
   if not (hostname and token):
-    err("No hostname or token, rum 'canvaslms login'")
+    err(1, "No hostname or token, run 'canvaslms login'")
 
   canvas = Canvas(hostname, token)
 
