@@ -8,30 +8,46 @@ import pypandoc
 import re
 import sys
 
-def add_assignment_option(parser):
+def add_assignment_option(parser, ungraded=True):
   try:
     courses.add_course_option(parser)
   except argparse.ArgumentError:
     pass
 
-  parser.add_argument("-U", "--ungraded", action="store_true",
-    help="Filter only assignments with ungraded submissions.")
+  if ungraded:
+    parser.add_argument("-U", "--ungraded", action="store_true",
+      help="Filter only assignments with ungraded submissions.")
+
   parser.add_argument("-a", "--assignment",
     required=False, default=".*",
     help="Regex matching assignment title or Canvas identifier, "
       "default: '.*'")
+
   parser.add_argument("-A", "--assignment-group",
-    required=False, default=".*",
-    help="Regex matching assignment group title or Canvas identifier, "
-      "default: '.*'")
+    required=False, default="",
+    help="Regex matching assignment group title or Canvas identifier.")
 
 def process_assignment_option(canvas, args):
   course_list = courses.process_course_option(canvas, args)
   assignments_list = []
 
   for course in course_list:
-    all_assignments = list(list_assignments([course], ungraded=args.ungraded))
-    assignment_groups = filter_assignment_groups(course, args.assignment_group)
+    try:
+      ungraded = args.ungraded
+    except AttributeError:
+      ungraded = False
+
+    all_assignments = list(filter_assignments([course],
+      args.assignment,
+      ungraded=ungraded))
+
+    try:
+      assignm_grp_regex = args.assignment_group
+    except AttributeError:
+      print("default to .* for group")
+      assignm_grp_regex = ".*"
+
+    assignment_groups = filter_assignment_groups(course, assignm_grp_regex)
 
     for assignment_group in assignment_groups:
       assignments_list += list(filter_assignments_by_group(
@@ -99,11 +115,11 @@ def list_assignments(assignments_containers, ungraded=False):
 
 def list_ungraded_assignments(assignments_containers):
   return list_assignments(assignments_containers, ungraded=True)
-def filter_assignments(assaignments_containers, regex):
+def filter_assignments(assignments_containers, regex, ungraded=False):
   """Returns all assignments from assignments_container whose
   title matches regex"""
   p = re.compile(regex)
-  for assignment in list_assignments(assignments_containers):
+  for assignment in list_assignments(assignments_containers, ungraded=ungraded):
     if p.search(assignment.name):
       yield assignment
     elif p.search(str(assignment.id)):
