@@ -70,9 +70,13 @@ def process_submission_options(canvas, args):
   user_list = users.process_user_or_group_option(canvas, args)
 
   if args.ungraded:
-    submissions = list_ungraded_submissions(assignment_list)
+    submissions = list_ungraded_submissions(assignment_list,
+      include=["submission_history", "submission_comments", 
+      "rubric_assessment"])
   else:
-    submissions = list_submissions(assignment_list)
+    submissions = list_submissions(assignment_list,
+      include=["submission_history", "submission_comments", 
+      "rubric_assessment"])
 
   return list(filter_submissions(submissions, user_list))
 def list_submissions(assignments, include=["submission_comments"]):
@@ -124,6 +128,17 @@ def format_submission(submission, canvas):
 - SpeedGrader: {speedgrader(submission)}
 """
 
+  try:
+    if submission.rubric_assessment:
+      formatted_submission += f"""
+
+# Rubric assessment
+
+{format_rubric(submission)}
+"""
+  except AttributeError:
+    pass
+
   try:
     if submission.submission_comments:
       formatted_submission += f"""
@@ -140,12 +155,16 @@ def format_submission(submission, canvas):
   except AttributeError:
     pass
 
-  formatted_submission += f"""
+  try:
+    if submission.body:
+      formatted_submission += f"""
 
 # Body
 
 {submission.body}
 """
+  except AttributeError:
+    pass
 
   try:
     for attachment in submission.attachments:
@@ -165,6 +184,38 @@ def format_submission(submission, canvas):
     pass
 
   return formatted_submission
+def format_rubric(submission):
+  """Format the rubric assessment of the `submission` in readable form."""
+
+  result = ""
+
+  for crit_id, rating_data in submission.rubric_assessment.items():
+    criterion = get_criterion(crit_id, submission.assignment.rubric)
+    rating = get_rating(rating_data["rating_id"], criterion)
+
+    result += f"{criterion['description']}: {rating['description']} " \
+      f"({rating['points']})\n"
+
+    if rating_data["comments"]:
+      result += f"Comments: {rating_data['comments']}\n"
+
+    result += "\n"
+
+  return result.strip()
+def get_criterion(criterion_id, rubric):
+  """Returns criterion with ID `criterion_id` from rubric `rubric`"""
+  for criterion in rubric:
+    if criterion["id"] == criterion_id:
+      return criterion
+
+  return None
+def get_rating(rating_id, criterion):
+  """Returns rating with ID `rating_id` from rubric criterion `criterion`"""
+  for rating in criterion["ratings"]:
+    if rating["id"] == rating_id:
+      return rating
+
+  return None
 
 def add_command(subp):
   """Adds the submissions and submission commands to argparse parser subp"""
